/*
    appwizard.c
    Copyright (C) 2000  Kh. Naba Kumar Singh

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <ctype.h>

#include <gnome.h>

#include "anjuta.h"
#include "messagebox.h"
#include "resources.h"
#include "appwizard.h"

AppWizard *
app_wizard_new (void)
{
	AppWizard *aw = g_malloc (sizeof (AppWizard));
	if (aw)
	{
		gchar* username;
		
		username = preferences_get(app->preferences, IDENT_NAME);
		if (!username)
		{
			username = getenv ("USERNAME");
			if (!username)
				username = getenv ("USER");
			if (!username)
				username = "Unknown";
			username = g_strdup(username);
		}
		aw->prj_type = PROJECT_TYPE_NOSTUB;
		aw->target_type = PROJECT_TARGET_TYPE_EXECUTABLE;
		aw->prj_name = NULL;
		aw->target = NULL;
		aw->author = g_strdup (username);
		g_free(username);
		aw->version = g_strdup ("0.1");
		aw->description = NULL;
		
		aw->cur_page = 0;
		
		aw->doors_comment = NULL;
		aw->minAMS = NULL;
		
		aw->dll_id = NULL;
		aw->dll_major_version = NULL;
		aw->dll_minor_version = NULL;
		
		aw->use_header = TRUE;
		aw->optimize_ROM_calls = TRUE;
		aw->save_restore_LCD = TRUE;
		aw->return_err_to_AMS = TRUE;
		aw->platform_89_support = FALSE;
		aw->platform_92p_support = FALSE;
		aw->platform_v200_support = FALSE;
		
		create_app_wizard_gui (aw);
		create_app_wizard_page1 (aw);
		create_app_wizard_page2 (aw);
		create_app_wizard_page3 (aw);
		create_app_wizard_page4 (aw);
	}
	return aw;
}

void
app_wizard_proceed (void)
{
	AppWizard *aw;

	aw = app_wizard_new ();
	g_return_if_fail (GTK_IS_WIDGET (aw->widgets.window));
	gtk_widget_show (aw->widgets.window);
}

void
app_wizard_destroy (AppWizard * aw)
{
	gint i;
	
	g_return_if_fail (aw != NULL);

	gtk_widget_unref (aw->widgets.window);
	gtk_widget_unref (aw->widgets.druid);
	for (i=0; i<6; i++)
	{
		gtk_widget_unref (aw->widgets.page[i]);
	}
	gtk_widget_unref (aw->widgets.prj_name_entry);
	gtk_widget_unref (aw->widgets.author_entry);
	gtk_widget_unref (aw->widgets.version_entry);
	gtk_widget_unref (aw->widgets.target_entry);
	gtk_widget_unref (aw->widgets.description_text);
	gtk_widget_unref (aw->widgets.file_header_check);
	gtk_widget_unref (aw->widgets.doors_frame);
	gtk_widget_unref (aw->widgets.doors_comment_entry);
	gtk_widget_unref (aw->widgets.dll_frame);	
	gtk_widget_unref (aw->widgets.dll_id_spinbutton);	
	gtk_widget_unref (aw->widgets.dll_minor_version_spinbutton);	
	gtk_widget_unref (aw->widgets.dll_major_version_spinbutton);	
	
	gtk_widget_unref (aw->widgets.target_exec_radio);
	gtk_widget_unref (aw->widgets.target_slib_radio);
	gtk_widget_unref (aw->widgets.target_dlib_radio);

	gtk_widget_unref (aw->widgets.platform_89_check);
	gtk_widget_unref (aw->widgets.platform_92p_check);
	gtk_widget_unref (aw->widgets.platform_v200_check);
	gtk_widget_unref (aw->widgets.min_AMS_version_spinbutton);
	gtk_widget_unref (aw->widgets.return_err_to_AMS_check);
	gtk_widget_unref (aw->widgets.optimize_ROM_calls_check);
	gtk_widget_unref (aw->widgets.save_restore_LCD_check);

	if (GTK_IS_WIDGET (aw->widgets.window))
		gtk_widget_destroy (aw->widgets.window);
	string_assign (&aw->prj_name, NULL);
	string_assign (&aw->target, NULL);
	string_assign (&aw->author, NULL);
	string_assign (&aw->version, NULL);
	string_assign (&aw->dll_id , NULL);
	string_assign (&aw->dll_major_version, NULL);
	string_assign (&aw->dll_minor_version, NULL);
	string_assign (&aw->minAMS, NULL);
	string_assign (&aw->doors_comment, NULL);
	
	g_free (aw);
}
