/*
    project_type.c
    Copyright (C) 2001  Johannes Schmid

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <glib.h>
#include <time.h>
#include <string.h>

#include "project_dbase.h"
#include "anjuta.h"

gchar* project_type_nostub[] = {	
	0, // gnome_project save string
	
	"", // cflags
	"", // ldadd
	
	"", // configure macros
	
	"/autogen.sh.generic", // autogen file
	
	"0", // gnome support
	"0", // gnome2 support
	"0" // glade support
};

gchar* project_type_kernelbased[] = {	
	0, // gnome_project save string
	
	"", // cflags
	"", // ldadd
	
	"", // configure macros
	
	"/autogen.sh.generic", // autogen file
	
	"0", // gnome support
	"0", // gnome2 support
	"0" // glade support
};

Project_Type* load_type_from_data(char* type_data[], gint id);

Project_Type* load_project_type(gint id)
{
	Project_Type* type;
	
	switch (id)
	{
		case PROJECT_TYPE_NOSTUB:
		{
			type = load_type_from_data(project_type_nostub, id);
			break;
		}
		case PROJECT_TYPE_KERNELBASED:
		{
			type = load_type_from_data(project_type_kernelbased, id);
			break;
		}
		default:
		{
			anjuta_error("Unknown project type!");
			return NULL;
		}
	}
	return type;
}

void free_project_type(Project_Type* type)
{
	g_free(type);
}

Project_Type* load_type_from_data(char* type_data[], gint id)
{
	Project_Type* type = g_malloc(sizeof(Project_Type));
	
	type->id = id;
	type->name = project_type_map[id];
	type->save_string = type_data[0];
	
	type->cflags = type_data[1];
	type->ldadd = type_data[2];
		
	type->configure_macros = type_data[3];
	type->autogen_file = type_data[4];
			
	type->gnome_support = atoi(type_data[5]);
	type->gnome2_support = atoi(type_data[6]);
	type->glade_support = atoi(type_data[7]);
	
	return type;
}
