/*  wizard_gui.c
 *  Copyright (C) 2002 Johannes Schmid
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/* Here is the code stored which is shared between appwizard and importwizard */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "wizard_gui.h"
#include "anjuta.h"
#include "pixmaps.h"
#include "resources.h"

GtkWidget *
create_project_start_page (GnomeDruid * druid, gchar * greetings,
			   gchar * title)
{
	GdkColor pagestart_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor pagestart_logo_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor pagestart_textbox_color = { 0, 65535, 65535, 65535 };
	GdkColor pagestart_title_color = { 0, 65535, 65535, 65535 };
	GtkWidget *page;

	page = gnome_druid_page_start_new ();
	gtk_widget_show (page);
	gnome_druid_append_page (GNOME_DRUID (druid),
				 GNOME_DRUID_PAGE (page));
	gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (page));
	gnome_druid_page_start_set_bg_color (GNOME_DRUID_PAGE_START
					     (page), &pagestart_bg_color);
	gnome_druid_page_start_set_logo_bg_color (GNOME_DRUID_PAGE_START
						  (page),
						  &pagestart_logo_bg_color);
	gnome_druid_page_start_set_textbox_color (GNOME_DRUID_PAGE_START
						  (page),
						  &pagestart_textbox_color);
	gnome_druid_page_start_set_title_color (GNOME_DRUID_PAGE_START
						(page),
						&pagestart_title_color);
	gnome_druid_page_start_set_text (GNOME_DRUID_PAGE_START
					 (page), greetings);
	gnome_druid_page_start_set_title (GNOME_DRUID_PAGE_START
					  (page), title);
	gnome_druid_page_start_set_logo (GNOME_DRUID_PAGE_START
					 (page),
					 anjuta_res_get_image
					 (ANJUTA_PIXMAP_APPWIZ_LOGO));
	gnome_druid_page_start_set_watermark (GNOME_DRUID_PAGE_START
					      (page),
					      anjuta_res_get_image
					      (ANJUTA_PIXMAP_APPWIZ_WATERMARK));

	return page;
}

GtkWidget *
create_project_type_selection_page (GnomeDruid * druid, GtkWidget ** iconlist)
{
	GtkWidget *frame;
	GtkWidget *frame3;
	GtkWidget *vbox4;
	GtkWidget *scrolledwindow1;
	GtkWidget *iconlist1;
	GtkWidget *frame2;
	GtkWidget *label2;
	GtkWidget *druid_vbox1;

	gchar *icon1_file, *icon2_file;

	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_title_color = { 0, 65535, 65535, 65535 };

	GtkWidget *page;

	page = gnome_druid_page_standard_new_with_vals ("", NULL);
	gtk_widget_show_all (page);
	gnome_druid_append_page (GNOME_DRUID (druid),
				 GNOME_DRUID_PAGE (page));
	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
						(page), &page_bg_color);
	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
						     (page),
						     &page_logo_bg_color);
	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
						   (page), &page_title_color);
	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
					     (page), _("Project Type"));
	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
					    (page),
					    anjuta_res_get_image
					    (ANJUTA_PIXMAP_APPWIZ_LOGO));

	frame = gtk_frame_new (NULL);
	gtk_widget_show (frame);
	druid_vbox1 = GNOME_DRUID_PAGE_STANDARD (page)->vbox;
	gtk_box_pack_start (GTK_BOX (druid_vbox1), frame, TRUE, TRUE, 0);

	vbox4 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox4);
	gtk_container_add (GTK_CONTAINER (frame), vbox4);

	frame2 = gtk_frame_new (NULL);
	gtk_widget_show (frame2);
	gtk_box_pack_start (GTK_BOX (vbox4), frame2, FALSE, FALSE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (frame2), 5);
	gtk_frame_set_shadow_type (GTK_FRAME (frame2), GTK_SHADOW_IN);

	label2 = gtk_label_new (_
				("Select the type of application to be developed"));
	gtk_misc_set_padding (GTK_MISC (label2), 5, 5);
	gtk_widget_show (label2);
	gtk_container_add (GTK_CONTAINER (frame2), label2);

	frame3 = gtk_frame_new (NULL);
	gtk_widget_show (frame3);
	gtk_box_pack_start (GTK_BOX (vbox4), frame3, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (frame3), 5);
	gtk_frame_set_shadow_type (GTK_FRAME (frame3), GTK_SHADOW_IN);

	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
	gtk_widget_show (scrolledwindow1);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1),
					GTK_POLICY_AUTOMATIC,
					GTK_POLICY_AUTOMATIC);
	gtk_container_add (GTK_CONTAINER (frame3), scrolledwindow1);

	iconlist1 = gnome_icon_list_new_flags (110, NULL, 0);
	gnome_icon_list_set_selection_mode (GNOME_ICON_LIST (iconlist1),
					    GTK_SELECTION_BROWSE);
	gtk_widget_show (iconlist1);
	gtk_container_add (GTK_CONTAINER (scrolledwindow1), iconlist1);
	gnome_icon_list_set_icon_border (GNOME_ICON_LIST (iconlist1), 5);
	gnome_icon_list_set_row_spacing (GNOME_ICON_LIST (iconlist1), 20);
	gnome_icon_list_set_text_spacing (GNOME_ICON_LIST (iconlist1), 5);

	icon1_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_NOSTUB);
	icon2_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_KERNELBASED);
	
	if (icon1_file)
		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
					icon1_file,
					_("No stub project"));

	if (icon2_file)
		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
					icon2_file, _("Kernel Based project"));

	g_free (icon1_file);
	g_free (icon2_file);

	*iconlist = iconlist1;
	return page;
};

GtkWidget *
create_project_props_page (GnomeDruid * druid,
			   GtkWidget ** prj_name,
			   GtkWidget ** author,
			   GtkWidget ** version,
			   GtkWidget ** target,
			   GtkWidget ** platform_89_check,
			   GtkWidget ** platform_92p_check,
			   GtkWidget ** platform_v200_check,
			   GtkWidget ** target_exec_radio,
			   GtkWidget ** target_slib_radio,
			   GtkWidget ** target_dlib_radio)
{
	GtkWidget *frame;
	GtkWidget *vbox3;
	GtkWidget *frame1;
	GtkWidget *hbox2;

	GtkWidget *table1;
	GtkWidget *label;
	GtkWidget *prj_name_entry;
	GtkWidget *version_entry;
	GtkWidget *target_entry;
	GtkWidget *author_entry;
	GtkWidget *druid_vbox2;

	GtkWidget *frame2;
	GtkWidget *hbox3;
	GSList *hbox3_group = NULL;
	
	GtkWidget *radiobutton1;
	GtkWidget *radiobutton2;
	GtkWidget *radiobutton3;
	
	GtkWidget *checkbutton4;
	GtkWidget *checkbutton5;
	GtkWidget *checkbutton6;

	GtkWidget *frame3;
	GtkWidget *hbox4;
	GtkWidget *hbox5;
	GSList *hbox5_group = NULL;
	
	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_title_color = { 0, 65535, 65535, 65535 };

	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL);
	gtk_widget_show_all (page);
	gnome_druid_append_page (GNOME_DRUID (druid),
				 GNOME_DRUID_PAGE (page));
	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
						(page), &page_bg_color);
	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
						     (page),
						     &page_logo_bg_color);
	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
						   (page), &page_title_color);
	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
					     (page), _("Basic Information"));
	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
					    (page),
					    anjuta_res_get_image
					    (ANJUTA_PIXMAP_APPWIZ_LOGO));

	frame = gtk_frame_new (NULL);
	gtk_widget_show (frame);
	druid_vbox2 = GNOME_DRUID_PAGE_STANDARD (page)->vbox;
	gtk_box_pack_start (GTK_BOX (druid_vbox2), frame, TRUE, TRUE, 0);

	vbox3 = gtk_vbox_new (FALSE, 5);
	gtk_widget_show (vbox3);
	gtk_container_add (GTK_CONTAINER (frame), vbox3);

	frame1 = gtk_frame_new (NULL);
	gtk_widget_show (frame1);
	gtk_box_pack_start (GTK_BOX (vbox3), frame1, FALSE, FALSE, 0);
	gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_IN);
	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);

	label = gtk_label_new (_("Enter the basic Project information"));
	gtk_widget_show (label);
	gtk_container_add (GTK_CONTAINER (frame1), label);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_FILL);
	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
	gtk_misc_set_padding (GTK_MISC (label), 5, 5);

	hbox2 = gtk_hbox_new (FALSE, 0);
	gtk_widget_show (hbox2);
	gtk_box_pack_start (GTK_BOX (vbox3), hbox2, TRUE, TRUE, 0);

	table1 = gtk_table_new (6, 2, FALSE);
	gtk_widget_show (table1);
	gtk_box_pack_start (GTK_BOX (hbox2), table1, TRUE, TRUE, 4);
	gtk_table_set_row_spacings (GTK_TABLE (table1), 6);

	label = gtk_label_new (_("Project Name:"));
	gtk_widget_show (label);
	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label, 0, 1, 0, 1,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	label = gtk_label_new (_("Project Version:"));
	gtk_widget_show (label);
	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label, 0, 1, 1, 2,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	label = gtk_label_new (_("Project Author:"));
	gtk_widget_show (label);
	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label, 0, 1, 2, 3,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	label = gtk_label_new (_("Project Target:"));
	gtk_widget_show (label);
	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label, 0, 1, 3, 4,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	prj_name_entry = gtk_entry_new ();
	gtk_widget_show (prj_name_entry);
	gtk_table_attach (GTK_TABLE (table1), prj_name_entry, 1, 2, 0, 1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);

	version_entry = gtk_entry_new ();
	gtk_widget_show (version_entry);
	gtk_table_attach (GTK_TABLE (table1), version_entry, 1, 2, 1, 2,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);

	author_entry = gtk_entry_new ();
	gtk_widget_show (author_entry);
	gtk_table_attach (GTK_TABLE (table1), author_entry, 1, 2, 2, 3,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);

	target_entry = gtk_entry_new ();
	gtk_widget_show (target_entry);
	gtk_table_attach (GTK_TABLE (table1), target_entry, 1, 2, 3, 4,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);

	frame2 = gtk_frame_new (_("Platform Support"));
	gtk_widget_show (frame2);
	gtk_table_attach (GTK_TABLE (table1), frame2, 1, 2, 4, 5,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);
	gtk_container_set_border_width (GTK_CONTAINER (frame2), 5);

	hbox3 = gtk_hbox_new (FALSE, 0);
	gtk_widget_show (hbox3);
	gtk_container_add (GTK_CONTAINER (frame2), hbox3);

	checkbutton4 = gtk_check_button_new_with_label (_("TI89"));
	gtk_widget_show (checkbutton4);
	gtk_box_pack_start (GTK_BOX (hbox3), checkbutton4, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (checkbutton4), 5);

	checkbutton5 =
		gtk_check_button_new_with_label (_("TI92 Plus"));
	gtk_widget_show (checkbutton5);
	gtk_box_pack_start (GTK_BOX (hbox3), checkbutton5, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (checkbutton5), 5);

	checkbutton6 =
		gtk_check_button_new_with_label (_("Voyage 200"));
	gtk_widget_show (checkbutton6);
	gtk_box_pack_start (GTK_BOX (hbox3), checkbutton6, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (checkbutton6), 5);
	
	frame3 = gtk_frame_new (_("Target type"));
	gtk_widget_show (frame3);
	gtk_table_attach (GTK_TABLE (table1), frame3, 1, 2, 5, 6,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);
	gtk_container_set_border_width (GTK_CONTAINER (frame3), 5);
	
	hbox4 = gtk_hbox_new (FALSE, 0);
	gtk_widget_show (hbox4);
	gtk_container_add (GTK_CONTAINER (frame3), hbox4);
	gtk_container_set_border_width (GTK_CONTAINER (hbox4), 5);
	
	hbox5 = gtk_hbox_new (FALSE, 0);
	gtk_widget_show (hbox5);
	gtk_box_pack_start (GTK_BOX (hbox4), hbox5, TRUE, TRUE, 0);
	
	radiobutton1 = gtk_radio_button_new_with_label (hbox5_group, _("Executable target"));
	hbox5_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton1));
	gtk_widget_show (radiobutton1);
	gtk_box_pack_start (GTK_BOX (hbox5), radiobutton1, FALSE, FALSE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (radiobutton1), 5);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton1), TRUE);
	
	radiobutton2 = gtk_radio_button_new_with_label (hbox5_group, _("Static library target"));
	hbox5_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton2));
	gtk_widget_show (radiobutton2);
	gtk_box_pack_start (GTK_BOX (hbox5), radiobutton2, FALSE, FALSE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (radiobutton2), 5);
	
	radiobutton3 = gtk_radio_button_new_with_label (hbox5_group, _("Dynamic library target"));
	hbox5_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton3));
	gtk_widget_show (radiobutton3);
	gtk_box_pack_start (GTK_BOX (hbox5), radiobutton3, FALSE, FALSE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (radiobutton3), 5);

	*prj_name = prj_name_entry;
	*author = author_entry;
	*version = version_entry;
	*target = target_entry;
	
	*platform_89_check = checkbutton4;
	*platform_92p_check = checkbutton5;
	*platform_v200_check = checkbutton6;
	
	if (target_exec_radio != NULL)
	{
		*target_exec_radio = radiobutton1;
		*target_slib_radio = radiobutton2;
		*target_dlib_radio = radiobutton3;
	}
	else
	{
		gtk_widget_set_sensitive(frame3, FALSE);
	}
	
	return page;
}

GtkWidget *
create_project_description_page (GnomeDruid * druid,
				 GtkWidget ** description)
{
	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_title_color = { 0, 65535, 65535, 65535 };

	GtkWidget *frame;
	GtkWidget *vbox3;
	GtkWidget *frame1;
	GtkWidget *label;
	GtkWidget *scrolledwindow1;
	GtkWidget *description_text;
	GtkWidget *druid_vbox3;
	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL);
	gtk_widget_show_all (page);
	gnome_druid_append_page (GNOME_DRUID (druid),
				 GNOME_DRUID_PAGE (page));
	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
						(page), &page_bg_color);
	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
						     (page),
						     &page_logo_bg_color);
	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
						   (page), &page_title_color);
	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
					     (page), _("Project Description"));
	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
					    (page),
					    anjuta_res_get_image
					    (ANJUTA_PIXMAP_APPWIZ_LOGO));

	frame = gtk_frame_new (NULL);
	gtk_widget_show (frame);
	druid_vbox3 = GNOME_DRUID_PAGE_STANDARD (page)->vbox;
	gtk_box_pack_start (GTK_BOX (druid_vbox3), frame, TRUE, TRUE, 0);

	vbox3 = gtk_vbox_new (FALSE, 5);
	gtk_widget_show (vbox3);
	gtk_container_add (GTK_CONTAINER (frame), vbox3);

	frame1 = gtk_frame_new (NULL);
	gtk_widget_show (frame1);
	gtk_box_pack_start (GTK_BOX (vbox3), frame1, FALSE, FALSE, 0);
	gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_IN);
	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);

	label = gtk_label_new (_("Enter a short description of the Project"));
	gtk_widget_show (label);
	gtk_container_add (GTK_CONTAINER (frame1), label);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_FILL);
	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
	gtk_misc_set_padding (GTK_MISC (label), 5, 5);

	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
	gtk_widget_show (scrolledwindow1);
	gtk_box_pack_start (GTK_BOX (vbox3), scrolledwindow1, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow1), 5);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1),
					GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);

	description_text = gtk_text_new (NULL, NULL);
	gtk_widget_show (description_text);
	gtk_container_add (GTK_CONTAINER (scrolledwindow1), description_text);
	gtk_text_set_editable (GTK_TEXT (description_text), TRUE);

	*description = description_text;
	return page;
}

GtkWidget *
create_project_menu_page (GnomeDruid * druid,
			  GtkWidget ** doors_frame,
			  GtkWidget ** doors_comment,
			  GtkWidget ** file_header_support,
			  GtkWidget ** optimize_ROM_calls,
	   		  GtkWidget ** return_err_to_AMS,
			  GtkWidget ** save_restore_LCD,
			  GtkWidget ** min_AMS_version,
			  GtkWidget ** dll_frame,
			  GtkWidget ** dll_id,		 
			  GtkWidget ** dll_major_version,
			  GtkWidget ** dll_minor_version)
{
	GtkWidget *frame;
	GtkWidget *vbox1;
	GtkWidget *vbox2;
	GtkWidget *vbox3;

	GtkWidget *frame4;
	GtkWidget *gpl_checkbutton;
	GtkWidget *optimize_checkbutton;
	GtkWidget *returnErr_checkbutton;
	GtkWidget *LCD_checkbutton;
	GtkWidget *minAMS_spinbutton;
	
	GtkWidget *frame1;
	GtkWidget *table1;
	GtkWidget *table0;
	GtkWidget *label;
	GtkWidget *label0;
	GtkWidget *label1;
	GtkWidget *label2;
	GtkWidget *label3;
	GtkWidget *entry1;
	GtkWidget *entry2;
	GtkWidget *combo1;
	GtkWidget *combo_entry1;
	GtkWidget *iconentry1;
	GtkWidget *checkbutton1;
	GtkWidget *druid_vbox4;
	GList *list;
	gint i;

	GtkWidget *frame5;
	GtkWidget *table2;
	GtkWidget *label4;
	GtkWidget *label5;
	GtkWidget *label6;
	GtkWidget *spinbutton1;
	GtkWidget *spinbutton2;
	GtkWidget *spinbutton3;
	
	GtkObject* adjust;	
	GtkObject* adjust1;
	GtkObject* adjust2;
	GtkObject* adjust3;
	
	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor page_title_color = { 0, 65535, 65535, 65535 };


	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL);
	gtk_widget_show_all (page);
	gnome_druid_append_page (GNOME_DRUID (druid),
				 GNOME_DRUID_PAGE (page));
	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
						(page), &page_bg_color);
	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
						     (page),
						     &page_logo_bg_color);
	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
						   (page), &page_title_color);
	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
					     (page), _("Additional Options"));
	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
					    (page),
					    anjuta_res_get_image
					    (ANJUTA_PIXMAP_APPWIZ_LOGO));

	frame = gtk_frame_new (NULL);
	gtk_widget_show (frame);
	druid_vbox4 = GNOME_DRUID_PAGE_STANDARD (page)->vbox;
	gtk_box_pack_start (GTK_BOX (druid_vbox4), frame, TRUE, TRUE, 0);

	vbox3 = gtk_vbox_new (FALSE, 5);
	gtk_widget_show (vbox3);
	gtk_container_add (GTK_CONTAINER (frame), vbox3);

	frame1 = gtk_frame_new (NULL);
	gtk_widget_show (frame1);
	gtk_box_pack_start (GTK_BOX (vbox3), frame1, FALSE, FALSE, 0);
	gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_IN);
	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);

	label = gtk_label_new (_("Enter any additional Project options"));
	gtk_widget_show (label);
	gtk_container_add (GTK_CONTAINER (frame1), label);
	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_FILL);
	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
	gtk_misc_set_padding (GTK_MISC (label), 5, 5);

	frame4 = gtk_frame_new (NULL);
	gtk_widget_show (frame4);
	gtk_container_add (GTK_CONTAINER (vbox3), frame4);
	gtk_container_set_border_width (GTK_CONTAINER (frame4), 5);
	gtk_frame_set_shadow_type (GTK_FRAME (frame4), GTK_SHADOW_IN);

	vbox1 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox1);
	gtk_container_add (GTK_CONTAINER (frame4), vbox1);

	frame = gtk_frame_new (_(" Project Options "));
	gtk_widget_show (frame);
	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
	gtk_box_pack_start (GTK_BOX (vbox1), frame, TRUE, TRUE, 0);

	vbox2 = gtk_vbox_new (FALSE, 0);
	gtk_widget_show (vbox2);
	gtk_container_add (GTK_CONTAINER (frame), vbox2);

	gpl_checkbutton =
		gtk_check_button_new_with_label (_
						 ("Include GNU Copyright statement in file headings"));
	gtk_widget_show (gpl_checkbutton);
	gtk_box_pack_start (GTK_BOX (vbox2), gpl_checkbutton, TRUE, TRUE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gpl_checkbutton),
				      TRUE);

	optimize_checkbutton =
		gtk_check_button_new_with_label (_
						 ("Optimize ROM calls"));
	gtk_widget_show (optimize_checkbutton);
	gtk_box_pack_start (GTK_BOX (vbox2), optimize_checkbutton, TRUE, TRUE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (optimize_checkbutton),
				      TRUE);

	LCD_checkbutton =
		gtk_check_button_new_with_label (_
						 ("Save/Restore LCD contents"));
	gtk_widget_show (LCD_checkbutton);
	gtk_box_pack_start (GTK_BOX (vbox2), LCD_checkbutton, TRUE, TRUE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (LCD_checkbutton),
				      TRUE);

	returnErr_checkbutton =
		gtk_check_button_new_with_label (_
						 ("Return error to AMS"));
	gtk_widget_show (returnErr_checkbutton);
	gtk_box_pack_start (GTK_BOX (vbox2), returnErr_checkbutton, TRUE, TRUE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (returnErr_checkbutton),
				      TRUE);

	table0 = gtk_table_new(1,2,FALSE);
	gtk_widget_show(table0);
	gtk_box_pack_start(GTK_BOX(vbox2), table0, TRUE, TRUE, 0);

	label0 = gtk_label_new (_("Minimum AMS version (default is 1.01):"));
	gtk_widget_show (label0);
	gtk_misc_set_alignment (GTK_MISC (label0), 0, -1);
	gtk_table_attach (GTK_TABLE (table0), label0, 0, 1, 0, 1,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	adjust = gtk_adjustment_new(1.01, 1.00, 2.08, 0.01, 1.0, 1.0); 
	minAMS_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT(adjust), 0.01, 3);
	gtk_widget_show (minAMS_spinbutton);
	gtk_table_attach (GTK_TABLE (table0), minAMS_spinbutton, 1, 2, 0, 1,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	frame1 = gtk_frame_new (_("Doors Entry"));
	gtk_widget_show (frame1);
	gtk_box_pack_start (GTK_BOX (vbox1), frame1, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);

	table1 = gtk_table_new (3, 3, FALSE);
	gtk_widget_show (table1);
	gtk_container_add (GTK_CONTAINER (frame1), table1);
	gtk_container_set_border_width (GTK_CONTAINER (table1), 5);

	/*label1 = gtk_label_new (_("Entry name:"));
	gtk_widget_show (label1);
	gtk_misc_set_alignment (GTK_MISC (label1), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label1, 0, 1, 0, 1,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);
*/
	label2 = gtk_label_new (_("Doors Comment:"));
	gtk_widget_show (label2);
	gtk_misc_set_alignment (GTK_MISC (label2), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label2, 0, 1, 1, 2,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);


	frame5 = gtk_frame_new (_("Dll Tags"));
	gtk_widget_show (frame5);
	gtk_box_pack_start (GTK_BOX (vbox1), frame5, TRUE, TRUE, 0);
	gtk_container_set_border_width (GTK_CONTAINER (frame5), 5);


	table2 = gtk_table_new (3, 3, FALSE);
	gtk_widget_show (table2);
	gtk_container_add (GTK_CONTAINER (frame5), table2);
	gtk_container_set_border_width (GTK_CONTAINER (table2), 5);

	label4 = gtk_label_new (_("Dll id:"));
	gtk_widget_show (label4);
	gtk_misc_set_alignment (GTK_MISC (label4), 0, -1);
	gtk_table_attach (GTK_TABLE (table2), label4, 0, 1, 0, 1,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	adjust1 = gtk_adjustment_new(1000, 0, (1<<16) - 1 /*(1<<32) - 1*/, 1, 10, 100); 
	spinbutton1 = gtk_spin_button_new (GTK_ADJUSTMENT(adjust1), 1, 0);
	gtk_widget_show (spinbutton1);
	gtk_table_attach (GTK_TABLE (table2), spinbutton1, 1, 2, 0, 1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	label5 = gtk_label_new (_("Dll major version number:"));
	gtk_widget_show (label5);
	gtk_misc_set_alignment (GTK_MISC (label5), 0, -1);
	gtk_table_attach (GTK_TABLE (table2), label5, 0, 1, 1, 2,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	adjust2 = gtk_adjustment_new(1, 0, (1<<16) - 1, 1, 10, 100); 
	spinbutton2 = gtk_spin_button_new (GTK_ADJUSTMENT(adjust2), 1, 0);
	gtk_widget_show (spinbutton2);
	gtk_table_attach (GTK_TABLE (table2), spinbutton2, 1, 2, 1, 2,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	label6 = gtk_label_new (_("Dll minor version number:"));
	gtk_widget_show (label6);
	gtk_misc_set_alignment (GTK_MISC (label6), 0, -1);
	gtk_table_attach (GTK_TABLE (table2), label6, 0, 1, 2, 3,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);

	adjust3 = gtk_adjustment_new(0, 0, (1<<16) - 1, 1, 10, 100); 
	spinbutton3 = gtk_spin_button_new (GTK_ADJUSTMENT(adjust3), 1, 0);
	gtk_widget_show (spinbutton3);
	gtk_table_attach (GTK_TABLE (table2), spinbutton3, 1, 2, 2, 3,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);



	/*label3 = gtk_label_new (_("Group:"));
	gtk_widget_show (label3);
	gtk_misc_set_alignment (GTK_MISC (label3), 0, -1);
	gtk_table_attach (GTK_TABLE (table1), label3, 0, 1, 2, 3,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 5, 0);
*/
	/*entry1 = gtk_entry_new ();
	gtk_widget_show (entry1);
	gtk_table_attach (GTK_TABLE (table1), entry1, 1, 2, 0, 1,
			  (GtkAttachOptions) (GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);
*/
	entry2 = gtk_entry_new ();
	gtk_widget_show (entry2);
	gtk_table_attach (GTK_TABLE (table1), entry2, 1, 2, 1, 2,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);

/*	combo1 = gtk_combo_new ();
	gtk_widget_show (combo1);
	gtk_table_attach (GTK_TABLE (table1), combo1, 1, 2, 2, 3,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (0), 0, 0);

	combo_entry1 = GTK_COMBO (combo1)->entry;
	gtk_entry_set_editable (GTK_ENTRY (combo_entry1), FALSE);

	list = NULL;
	i = 0;
	while (app_group[i])
		list = g_list_append (list, app_group[i++]);
	gtk_combo_set_popdown_strings (GTK_COMBO (combo1), list);
	g_list_free (list);

	iconentry1 =
		gnome_icon_entry_new (NULL, "Select an Application Icon");
	gtk_widget_show (iconentry1);
	gtk_table_attach (GTK_TABLE (table1), iconentry1, 2, 3, 0, 2,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions) (GTK_FILL), 0, 0);

	checkbutton1 = gtk_check_button_new_with_label (_("Needs terminal"));
	gtk_widget_show (checkbutton1);
	gtk_table_attach (GTK_TABLE (table1), checkbutton1, 2, 3, 2, 3,
			  (GtkAttachOptions) (0),
			  (GtkAttachOptions) (0), 0, 0);
	gtk_container_set_border_width (GTK_CONTAINER (checkbutton1), 5);
*/
	*file_header_support = gpl_checkbutton;
	*doors_frame = frame1;
	*doors_comment = entry2;
	*save_restore_LCD = LCD_checkbutton;
	*optimize_ROM_calls = optimize_checkbutton;
	*return_err_to_AMS = returnErr_checkbutton;
	*min_AMS_version = minAMS_spinbutton;
	*dll_frame = frame5;
	*dll_id = spinbutton1;
	*dll_major_version = spinbutton2;
	*dll_minor_version = spinbutton3;
	
	return page;
}

GtkWidget *
create_project_finish_page (GnomeDruid * druid)
{
	GdkColor pagefinish_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor pagefinish_logo_bg_color = { 0, 15616, 33280, 46848 };
	GdkColor pagefinish_textbox_color = { 0, 65535, 65535, 65535 };
	GdkColor pagefinish_title_color = { 0, 65535, 65535, 65535 };

	GtkWidget *page = gnome_druid_page_finish_new ();
	gtk_widget_show (page);
	gnome_druid_append_page (GNOME_DRUID (druid),
				 GNOME_DRUID_PAGE (page));
	gnome_druid_page_finish_set_bg_color (GNOME_DRUID_PAGE_FINISH
					      (page), &pagefinish_bg_color);
	gnome_druid_page_finish_set_logo_bg_color (GNOME_DRUID_PAGE_FINISH
						   (page),
						   &pagefinish_logo_bg_color);
	gnome_druid_page_finish_set_textbox_color (GNOME_DRUID_PAGE_FINISH
						   (page),
						   &pagefinish_textbox_color);
	gnome_druid_page_finish_set_title_color (GNOME_DRUID_PAGE_FINISH
						 (page),
						 &pagefinish_title_color);
	gnome_druid_page_finish_set_title (GNOME_DRUID_PAGE_FINISH
					   (page), _("Summary"));
	gnome_druid_page_finish_set_logo (GNOME_DRUID_PAGE_FINISH
					  (page),
					  anjuta_res_get_image
					  (ANJUTA_PIXMAP_APPWIZ_LOGO));
	gnome_druid_page_finish_set_watermark (GNOME_DRUID_PAGE_FINISH
					       (page),
					       anjuta_res_get_image
					       (ANJUTA_PIXMAP_APPWIZ_WATERMARK));

	return page;
}

